import React from 'react';
import { Server, Cpu, MemoryStick as Memory, Trash2, ExternalLink } from 'lucide-react';
import type { Server as ServerType } from '../types';

interface ServerCardProps {
  server: ServerType;
  onDelete: (id: string) => void;
}

export function ServerCard({ server, onDelete }: ServerCardProps) {
  const handleProxmoxClick = () => {
    window.open(server.proxmox_url, '_blank');
  };

  return (
    <div 
      className="bg-gray-800/50 backdrop-blur-sm rounded-xl p-6 hover:bg-gray-700/50 transition-all duration-300 cursor-pointer transform hover:scale-102 hover:shadow-xl hover:shadow-purple-500/10 border border-gray-700/50"
      onClick={handleProxmoxClick}
    >
      <div className="flex items-center justify-between mb-6">
        <h3 className="text-xl font-semibold text-white flex items-center gap-2 group">
          <Server className="text-purple-400 group-hover:text-purple-300 transition-colors" size={24} />
          <span className="group-hover:text-purple-300 transition-colors">{server.name}</span>
          <ExternalLink size={16} className="text-purple-400 group-hover:text-purple-300 transition-colors" />
        </h3>
        <button
          onClick={(e) => {
            e.stopPropagation();
            onDelete(server.id);
          }}
          className="text-gray-400 hover:text-red-400 transition-colors p-2 hover:bg-red-400/10 rounded-lg"
          title="Delete server"
        >
          <Trash2 size={18} />
        </button>
      </div>
      
      <div className="space-y-4">
        <div className="flex items-center gap-2 text-gray-300 bg-gray-800/50 p-3 rounded-lg">
          <span className="text-gray-400 min-w-[4rem]">Model:</span>
          <span className="font-medium">{server.model}</span>
        </div>
        
        <div className="bg-gray-800/50 p-4 rounded-lg space-y-3">
          <div className="flex items-center gap-2 mb-2">
            <Cpu size={18} className="text-purple-400" />
            <span className="text-gray-300 font-medium">CPU Information</span>
          </div>
          
          <div className="pl-7 space-y-2">
            <div className="flex items-center gap-2">
              <span className="text-gray-400">Model:</span>
              <span className="text-gray-200 font-medium">{server.cpu_model}</span>
            </div>
            <div className="flex items-center gap-2">
              <span className="text-gray-400">Cores:</span>
              <span className="text-gray-200 font-medium">{server.cpu_cores} cores</span>
            </div>
          </div>
        </div>
        
        <div className="flex items-center gap-2 text-gray-300 bg-gray-800/50 p-3 rounded-lg">
          <Memory size={18} className="text-purple-400 min-w-[1.5rem]" />
          <div>
            <div className="font-medium">{server.ram_gb} GB</div>
            <div className="text-sm text-gray-400">RAM</div>
          </div>
        </div>
      </div>
    </div>
  );
}